@@ -127,7 +127,7 @@ from kivy.properties import ListProperty                        # type: ignore #
 from ae.base import UNSET                                       # type: ignore
 
 
-__version__ = '0.2.11'
+__version__ = '0.3.12'
 
 
 DEFAULT_FPS = 30.0                                              #: default frames-per-second
@@ -420,7 +420,7 @@ class ShadersMixin:
 
     # attributes
     added_shaders = ListProperty()                  #: list of shader-ids/kwarg-dicts for each shader
-    running_shaders: List[ShaderIdType] = list()    #: list/pool of active/running shaders/render-contexts
+    running_shaders: List[ShaderIdType] = []        #: list/pool of active/running shaders/render-contexts
 
     _pos_fbind_uid: int = 0
     _size_fbind_uid: int = 0
@@ -476,7 +476,7 @@ class ShadersMixin:
         if 'center_pos' not in glsl_dyn_args:
             glsl_dyn_args['center_pos'] = lambda: (self.center_x, self.center_y)
         if 'tint_ink' not in glsl_dyn_args:
-            glsl_dyn_args['tint_ink'] = (0.546, 0.546, 0.546, 1.0)    # colors * shader_code.TWO ~= (1.0, 1.0, 1.0)
+            glsl_dyn_args['tint_ink'] = [0.546, 0.546, 0.546, 1.0]  # colors * shader_code.TWO ~= [1.0, 1.0, 1.0]
 
         shader_id = dict(add_to=add_to, run_state=run_state, render_shape=render_shape,
                          shader_code=shader_code, shader_file=shader_file,
@@ -592,7 +592,7 @@ class ShadersMixin:
             shader_id.update(added_to=added_to, render_ctx=ren_ctx)
 
             if not self.running_shaders:
-                self.running_shaders = list()  # create attribute on this instance (class attr untouched as emtpy list)
+                self.running_shaders = []      # create attribute on this instance (class attr untouched as emtpy list)
             self.running_shaders.append(shader_id)
 
             if update_freq:
